# coding=utf-8

import os
import codecs
from weppy.extensions import Extension, TemplateExtension
from .hamlpy import Compiler


class Haml(Extension):
    namespace = 'Haml'
    default_config = dict(
        set_as_default=False
    )

    def _load_config(self):
        self.config.set_as_default = self.config.get(
            'set_as_default', self.default_config['set_as_default'])

    def on_load(self):
        self._load_config()
        self.app.add_template_extension(HamlTemplate)
        if self.config.set_as_default:
            self.app.template_default_extension = '.haml'
        for path, dirs, files in os.walk(self.app.template_path):
            for fname in files:
                if os.path.splitext(fname)[1] == ".haml":
                    filepath = os.path.join(path, fname)
                    self.process(filepath)

    def process(self, filepath):
        haml_lines = codecs.open(
            filepath, 'r',
            encoding='utf-8').read().splitlines()
        compiler = Compiler()
        output = compiler.process_lines(haml_lines)
        outfile = codecs.open(filepath+".html", 'w', encoding='utf-8')
        outfile.write(output)


class HamlTemplate(TemplateExtension):
    namespace = 'Haml'
    file_extension = '.haml'

    def preload(self, path, name):
        return path, name+".html"



# -*- coding: utf-8 -*-
"""
weppy-Haml
----------

This extension make it possible to use a
`haml <http://haml-lang.com/>`_ syntax in weppy templates.
"""

from setuptools import setup

setup(
    name='weppy-Haml',
    version='0.1',
    url='',
    license='BSD',
    author='Giovanni Barillari',
    author_email='gi0baro@d4net.org',
    description='Haml syntax for weppy templates',
    #long_description=__doc__,
    packages=['weppy_haml'],
    install_requires=['weppy'],
    zip_safe=False,
    platforms='any',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Text Processing :: Markup :: HTML'
    ],
)